It's purpose is to be able to run Cucumber tests alongside testthat tests.
To do that, place a call to run() in one of the test-*.R files in your tests/testthat directory.
Arguments
- path
Path to the directory containing the
.featurefiles. Ifrun()is placed in atests/testthat/test-*.Rfile and you calltestthat::test_diror similar, it runs in thetests/testthatdirectory. The default value"."finds all feature files in thetests/testthatdirectory.- filter
If not NULL, only features with file names matching this regular expression will be executed. Matching is performed on the file name after it's stripped of ".feature".
If not NULL, filter scenarios by tag expression string (e.g.,
"@smoke and not @slow","@gui or @database"). Tag expressions supportand,or,notoperators and parentheses for grouping.- reporter
Optional reporter instance (testthat::Reporter or cucumber::CucumberReporter). If NULL, will use reporter from package options if available.
- ...
Additional arguments passed to
grepl().
Value
NULL, invisibly.
To get result and a report, use cucumber::test(), or inspect the result of testthat function call.